"""
This type stub file was generated by pyright.
"""

from typing import Optional

def caching_resolver(*, timeout: Optional[int] = ..., cache=...): # -> Resolver:
    ...

def validate_email_deliverability(domain: str, domain_i18n: str, timeout: Optional[int] = ..., dns_resolver=...): # -> dict[str, str] | dict[str, Any]:
    ...

