"""
This type stub file was generated by pyright.
"""

"""SPDX standard metadata parser expression grammars, with support for :pep:`639` keys."""
user_defined_license = ...
spdx_license_expression = ...
