"""
This type stub file was generated by pyright.
"""

"""This script generates locales based on ozi_core/data files."""
def load_locale_data() -> dict[str, str]:
    ...

if __name__ == '__main__':
    text = ...
